select — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

# select

class `camelot.view.wizard.pages.select.` `SelectFilePage`(parent=None)

  SelectFilePage is the file selection page of an import wizard

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

Comments
blog comments powered by Disqus